betty.extension.privatizer package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.privatizer package

## Module contents

Privatize people and associated data by determining if they are likely to be alive.

class betty.extension.privatizer.Privatizer

  Bases: `UserFacingExtension`, `PostLoader`

  Extend the Betty Application with privatization features.

  Parameters:

    - app (`betty.app.App`)

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  classmethod description() → betty.locale.Str

    Get the human-readable extension description.

    Return type:

      `betty.locale.Str`

  classmethod label() → betty.locale.Str

    Get the human-readable extension label.

    Return type:

      `betty.locale.Str`

  classmethod name() → str

    The machine name.

    Return type:

      `str`

  async post_load() → None

    Act on the ancestry having been loaded.

    This method is called immediately after `betty.load.Loader.load()`.

    Return type:

      `None`

  privatize() → None

    Privatize the project’s ancestry.

    Return type:

      `None`